---
title: "READ THIS NO MATTER WHAT, SERIOUSLY!!!"
description: "A couple of warnings before you start"
icon: 'warning'
---

import { Contributors } from '/snippets/contributors.mdx';

## Important considerations before you start

- **This is a work in progress project, please don't expect it to be perfect**

- **The API is not yet stable, please make sure you lock the version of the library before using it in production**

- **haolib IS already used in production by [hao.vc](https://hao.vc), so you do not need to worry about the risk of the project being abandoned.
The problem is exactly the opposite: it is too new and we are still adding new features, fixing bugs and changing the API.**


If you are ok with the above, let's get started!


## Top contributors

<Contributors contributors={
  [
    {
      name: 'HAO',
      picture: '/hao.png',
      description: 'HAO cat, the avatar of HAO.VC'
    }
    ,
    {
      name: 'Kamil Biktimirov',
      picture: 'https://hao.vc/assets/kamil-biktimirov-TG-oknG-.jpg',
      description: 'CTO and Co-founder of hao.vc; Some Kind Of Programmers Founder; The creator and maintainer of haolib'
    }
  ]
} />
